@@ -573,6 +573,21 @@ ges_pipeline_change_state (GstElement * element, GstStateChange transition)
         gst_element_set_locked_state (tmp->data, FALSE);
     }
       break;
+    case GST_STATE_CHANGE_PAUSED_TO_PLAYING:
+    {
+      GstElement *queue = gst_bin_get_by_name (GST_BIN (self->priv->playsink),
+          "vqueue");
+
+      if (queue) {
+        GST_INFO_OBJECT (self, "Setting playsink video queue max-size-time to"
+            " 2 seconds.");
+        g_object_set (G_OBJECT (queue), "max-size-buffers", 0,
+            "max-size-bytes", 0, "max-size-time", (gint64) 2 * GST_SECOND,
+            NULL);
+        gst_object_unref (queue);
+      }
+      break;
+    }
     default:
       break;
   }
@@ -583,6 +598,8 @@ ges_pipeline_change_state (GstElement * element, GstStateChange transition)
 
   switch (transition) {
     case GST_STATE_CHANGE_PAUSED_TO_READY:
+    case GST_STATE_CHANGE_READY_TO_NULL:
+    case GST_STATE_CHANGE_NULL_TO_NULL:
       _unlink_tracks (self);
       break;
     default:
@@ -637,7 +654,7 @@ get_compatible_unlinked_pad (GstElement * element, GESTrack * track)
   pads = gst_element_iterate_sink_pads (element);
   srccaps = ges_track_get_caps (track);
 
-  GST_DEBUG ("srccaps %" GST_PTR_FORMAT, srccaps);
+  GST_DEBUG_OBJECT (track, "srccaps %" GST_PTR_FORMAT, srccaps);
 
   while (!done) {
     switch (gst_iterator_next (pads, &paditem)) {
@@ -648,7 +665,7 @@ get_compatible_unlinked_pad (GstElement * element, GESTrack * track)
         if (!gst_pad_is_linked (testpad)) {
           GstCaps *sinkcaps = gst_pad_query_caps (testpad, NULL);
 
-          GST_DEBUG ("sinkccaps %" GST_PTR_FORMAT, sinkcaps);
+          GST_DEBUG_OBJECT (track, "sinkccaps %" GST_PTR_FORMAT, sinkcaps);
 
           if (gst_caps_can_intersect (srccaps, sinkcaps)) {
             res = gst_object_ref (testpad);
@@ -734,7 +751,8 @@ _link_track (GESPipeline * self, GESTrack * track)
     chain = new_output_chain_for_track (self, track);
 
   if (chain->tee) {
-    GST_INFO_OBJECT (self, "Chain is already built");
+    GST_INFO_OBJECT (self, "Chain is already built (%" GST_PTR_FORMAT ")",
+        chain->encodebinpad ? chain->encodebinpad : chain->playsinkpad);
 
     return;
   }
@@ -828,10 +846,11 @@ _link_track (GESPipeline * self, GESTrack * track)
         /* If no compatible static pad is available, request a pad */
         g_signal_emit_by_name (self->priv->encodebin, "request-pad", caps,
             &sinkpad);
-        gst_caps_unref (caps);
 
         if (G_UNLIKELY (sinkpad == NULL)) {
-          GST_INFO_OBJECT (self, "Couldn't get a pad from encodebin !");
+          GST_INFO_OBJECT (self, "Couldn't get a pad from encodebin for: %"
+              GST_PTR_FORMAT, caps);
+          gst_caps_unref (caps);
           gst_element_set_locked_state (GST_ELEMENT (track), TRUE);
 
           self->priv->not_rendered_tracks =
@@ -840,8 +859,11 @@ _link_track (GESPipeline * self, GESTrack * track)
 
           goto error;
         }
+
+        gst_caps_unref (caps);
       }
       chain->encodebinpad = sinkpad;
+      GST_INFO_OBJECT (track, "Linked to %" GST_PTR_FORMAT, sinkpad);
     }
 
     tmppad = gst_element_get_request_pad (chain->tee, "src_%u");
