@@ -22,10 +22,11 @@
 #define __GES_SCREENSHOT_H__
 
 #include <gst/gst.h>
+#include <ges/ges-prelude.h>
 
 G_BEGIN_DECLS
 
-GST_EXPORT GstSample *
+GES_API GstSample *
 ges_play_sink_convert_frame (GstElement * playsink, GstCaps * caps);
 
 G_END_DECLS
