@@ -20,6 +20,7 @@
 
 /**
  * SECTION: gesuriclip
+ * @title: GESUriClip
  * @short_description: An object for manipulating media files in a GESTimeline
  *
  * Represents all the output streams from a particular uri. It is assumed that
@@ -72,7 +73,7 @@ static GList *ges_uri_clip_create_track_elements (GESClip *
     clip, GESTrackType type);
 static GESTrackElement
     * ges_uri_clip_create_track_element (GESClip * clip, GESTrackType type);
-void ges_uri_clip_set_uri (GESUriClip * self, gchar * uri);
+static void ges_uri_clip_set_uri (GESUriClip * self, gchar * uri);
 
 gboolean
 uri_clip_set_max_duration (GESTimelineElement * element,
@@ -318,10 +319,15 @@ extractable_set_asset (GESExtractable * self, GESAsset * asset)
       if (GES_IS_SOURCE (tmp->data)) {
         GESTrack *track = ges_track_element_get_track (tmp->data);
 
-        if (track->type == GES_TRACK_TYPE_AUDIO && audio_source)
+        if (track->type == GES_TRACK_TYPE_AUDIO && audio_source) {
           ges_track_element_copy_properties (audio_source, tmp->data);
-        else if (track->type == GES_TRACK_TYPE_VIDEO && video_source)
+          ges_track_element_copy_bindings (GES_TRACK_ELEMENT (audio_source),
+              tmp->data, GST_CLOCK_TIME_NONE);
+        } else if (track->type == GES_TRACK_TYPE_VIDEO && video_source) {
           ges_track_element_copy_properties (video_source, tmp->data);
+          ges_track_element_copy_bindings (GES_TRACK_ELEMENT (video_source),
+              tmp->data, GST_CLOCK_TIME_NONE);
+        }
       }
     }
 
