@@ -140,16 +140,30 @@ struct _NleCompositionPrivate
   /* List of NleObject whose start/duration will be the same as the composition */
   GList *expandables;
 
-  /*
-     current segment seek start/stop time.
-     Reconstruct pipeline ONLY if seeking outside of those values
-     FIXME : segment_start isn't always the earliest time before which the
-     timeline doesn't need to be modified
+  /* currently configured stack seek start/stop time.
+   * In forward playback:
+   *   - current_stack_start: The start of the current stack or the start value
+   *     of the seek if the stack has been seeked 'in the middle'
+   *   - current_stack_stop: The stop time of the current stack
+   *
+   * Reconstruct pipeline ONLY if seeking outside of those values
+   * FIXME : current_stack_start isn't always the earliest time before which the
+   * timeline doesn't need to be modified
    */
-  GstClockTime segment_start;
-  GstClockTime segment_stop;
+  GstClockTime current_stack_start;
+  GstClockTime current_stack_stop;
 
   /* Seek segment handler */
+  /* Represents the current segment that is being played,
+   * In forwards playback (logic is the same but swapping start and
+   * stop in backward playback):
+   *  - segment->start: start of the current segment being played,
+   *    at each stack change it will advance to the newly configured
+   *    stack start.
+   *  - segment->stop is the final stop of the segment being played.
+   *    if a seek with a stop time happened, it will be the stop time
+   *    otherwise, it will be the composition duration.
+   */
   GstSegment *segment;
   GstSegment *outside_segment;
 
@@ -181,7 +195,7 @@ struct _NleCompositionPrivate
 
   /* 0 means that we already received the right caps or segment */
   gint seqnum_to_restart_task;
-  gboolean waiting_for_buffer;
+  gboolean waiting_serialized_query_or_buffer;
 
   gboolean tearing_down_stack;
 
@@ -195,8 +209,8 @@ static guint _signals[LAST_SIGNAL] = { 0 };
 static GParamSpec *nleobject_properties[NLEOBJECT_PROP_LAST];
 
 #define OBJECT_IN_ACTIVE_SEGMENT(comp,element)      \
-  ((NLE_OBJECT_START(element) < comp->priv->segment_stop) &&  \
-   (NLE_OBJECT_STOP(element) >= comp->priv->segment_start))
+  ((NLE_OBJECT_START(element) < comp->priv->current_stack_stop) &&  \
+   (NLE_OBJECT_STOP(element) >= comp->priv->current_stack_start))
 
 static void nle_composition_dispose (GObject * object);
 static void nle_composition_finalize (GObject * object);
@@ -538,6 +552,10 @@ _seek_pipeline_func (NleComposition * comp, SeekData * seekd)
   GST_DEBUG_OBJECT (seekd->comp, "Segment now has flags:%d",
       priv->segment->flags);
 
+  /* FIXME: The idea was to avoid seeking on a stack if we know we will endup
+   * passed the end, but then we loose the flush, wich leads to hangs. Long
+   * term, we should just flush the stack instead to avoid the double seek. */
+#if 0
   if (priv->segment->start >= NLE_OBJECT_STOP (seekd->comp)) {
     GST_INFO_OBJECT (seekd->comp,
         "Start %" GST_TIME_FORMAT " > comp->stop: %" GST_TIME_FORMAT
@@ -546,6 +564,7 @@ _seek_pipeline_func (NleComposition * comp, SeekData * seekd)
     GST_FIXME_OBJECT (seekd->comp, "HANDLE error async!");
     return;
   }
+#endif
 
   _post_start_composition_update (seekd->comp,
       gst_event_get_seqnum (seekd->event), COMP_UPDATE_STACK_ON_SEEK);
@@ -1181,8 +1200,8 @@ nle_composition_reset (NleComposition * comp)
 
   _assert_proper_thread (comp);
 
-  priv->segment_start = GST_CLOCK_TIME_NONE;
-  priv->segment_stop = GST_CLOCK_TIME_NONE;
+  priv->current_stack_start = GST_CLOCK_TIME_NONE;
+  priv->current_stack_stop = GST_CLOCK_TIME_NONE;
   priv->next_base_time = 0;
 
   gst_segment_init (priv->segment, GST_FORMAT_TIME);
@@ -1213,8 +1232,9 @@ ghost_event_probe_handler (GstPad * ghostpad G_GNUC_UNUSED,
   NleCompositionPrivate *priv = comp->priv;
   GstEvent *event;
 
-  if (GST_IS_BUFFER (info->data)) {
-    if (priv->waiting_for_buffer) {
+  if (GST_IS_BUFFER (info->data) ||
+      (GST_IS_QUERY (info->data) && GST_QUERY_IS_SERIALIZED (info->data))) {
+    if (priv->waiting_serialized_query_or_buffer) {
       GST_INFO_OBJECT (comp, "update_pipeline DONE");
       _restart_task (comp);
     }
@@ -1368,12 +1388,13 @@ have_to_update_pipeline (NleComposition * comp,
       GST_TIME_FORMAT "--%" GST_TIME_FORMAT "]",
       GST_TIME_ARGS (priv->segment->start),
       GST_TIME_ARGS (priv->segment->stop),
-      GST_TIME_ARGS (priv->segment_start), GST_TIME_ARGS (priv->segment_stop));
+      GST_TIME_ARGS (priv->current_stack_start),
+      GST_TIME_ARGS (priv->current_stack_stop));
 
-  if (priv->segment->start < priv->segment_start)
+  if (priv->segment->start < priv->current_stack_start)
     return TRUE;
 
-  if (priv->segment->start >= priv->segment_stop)
+  if (priv->segment->start >= priv->current_stack_stop)
     return TRUE;
 
   return FALSE;
@@ -1394,7 +1415,7 @@ nle_composition_commit_func (NleObject * object, gboolean recurse)
  * Returns a seek event for the currently configured segment
  * and start/stop values
  *
- * The GstSegment and segment_start|stop must have been configured
+ * The GstSegment and current_stack_start|stop must have been configured
  * before calling this function.
  */
 static GstEvent *
@@ -1412,21 +1433,21 @@ get_new_seek_event (NleComposition * comp, gboolean initial,
     flags |= (GstSeekFlags) priv->segment->flags;
 
   GST_DEBUG_OBJECT (comp,
-      "private->segment->start:%" GST_TIME_FORMAT " segment_start%"
+      "private->segment->start:%" GST_TIME_FORMAT " current_stack_start%"
       GST_TIME_FORMAT, GST_TIME_ARGS (priv->segment->start),
-      GST_TIME_ARGS (priv->segment_start));
+      GST_TIME_ARGS (priv->current_stack_start));
 
   GST_DEBUG_OBJECT (comp,
-      "private->segment->stop:%" GST_TIME_FORMAT " segment_stop%"
+      "private->segment->stop:%" GST_TIME_FORMAT " current_stack_stop%"
       GST_TIME_FORMAT, GST_TIME_ARGS (priv->segment->stop),
-      GST_TIME_ARGS (priv->segment_stop));
+      GST_TIME_ARGS (priv->current_stack_stop));
 
   start = GST_CLOCK_TIME_IS_VALID (priv->segment->start)
-      ? MAX (priv->segment->start, priv->segment_start)
-      : priv->segment_start;
+      ? MAX (priv->segment->start, priv->current_stack_start)
+      : priv->current_stack_start;
   stop = GST_CLOCK_TIME_IS_VALID (priv->segment->stop)
-      ? MIN (priv->segment->stop, priv->segment_stop)
-      : priv->segment_stop;
+      ? MIN (priv->segment->stop, priv->current_stack_stop)
+      : priv->current_stack_stop;
 
   if (updatestoponly) {
     starttype = GST_SEEK_TYPE_NONE;
@@ -1504,8 +1525,8 @@ get_current_position (NleComposition * comp)
 beach:
 
   if (!GST_CLOCK_TIME_IS_VALID (value)) {
-    if (GST_CLOCK_TIME_IS_VALID (comp->priv->segment_start)) {
-      value = comp->priv->segment_start;
+    if (GST_CLOCK_TIME_IS_VALID (comp->priv->current_stack_start)) {
+      value = comp->priv->current_stack_start;
     } else {
       GST_INFO_OBJECT (comp, "Current position is unknown, " "setting it to 0");
 
@@ -1656,12 +1677,13 @@ nle_composition_event_handler (GstPad * ghostpad, GstObject * parent,
 
       GST_DEBUG_OBJECT (comp,
           "timestamp:%" GST_TIME_FORMAT " segment.start:%" GST_TIME_FORMAT
-          " segment.stop:%" GST_TIME_FORMAT " segment_start%" GST_TIME_FORMAT
-          " segment_stop:%" GST_TIME_FORMAT, GST_TIME_ARGS (timestamp),
+          " segment.stop:%" GST_TIME_FORMAT " current_stack_start%"
+          GST_TIME_FORMAT " current_stack_stop:%" GST_TIME_FORMAT,
+          GST_TIME_ARGS (timestamp),
           GST_TIME_ARGS (priv->outside_segment->start),
           GST_TIME_ARGS (priv->outside_segment->stop),
-          GST_TIME_ARGS (priv->segment_start),
-          GST_TIME_ARGS (priv->segment_stop));
+          GST_TIME_ARGS (priv->current_stack_start),
+          GST_TIME_ARGS (priv->current_stack_stop));
 
       /* The problem with QoS events is the following:
        * At each new internal segment (i.e. when we re-arrange our internal
@@ -1697,9 +1719,9 @@ nle_composition_event_handler (GstPad * ghostpad, GstObject * parent,
         gst_event_unref (event);
 
         if (priv->segment->rate < 0.0)
-          curdiff = priv->outside_segment->stop - priv->segment_stop;
+          curdiff = priv->outside_segment->stop - priv->current_stack_stop;
         else
-          curdiff = priv->segment_start - priv->outside_segment->start;
+          curdiff = priv->current_stack_start - priv->outside_segment->start;
         GST_DEBUG ("curdiff %" GST_TIME_FORMAT, GST_TIME_ARGS (curdiff));
         if ((curdiff != 0) && ((timestamp < curdiff)
                 || (curdiff > timestamp + diff))) {
@@ -1790,7 +1812,8 @@ nle_composition_ghost_pad_set_target (NleComposition * comp, GstPad * target)
     priv->ghosteventprobe =
         gst_pad_add_probe (target,
         GST_PAD_PROBE_TYPE_EVENT_DOWNSTREAM | GST_PAD_PROBE_TYPE_EVENT_FLUSH |
-        GST_PAD_PROBE_TYPE_DATA_DOWNSTREAM,
+        GST_PAD_PROBE_TYPE_DATA_DOWNSTREAM |
+        GST_PAD_PROBE_TYPE_QUERY_DOWNSTREAM,
         (GstPadProbeCallback) ghost_event_probe_handler, comp, NULL);
     GST_DEBUG_OBJECT (comp, "added event probe %lu", priv->ghosteventprobe);
   }
@@ -2238,7 +2261,7 @@ _restart_task (NleComposition * comp)
         G_PRIORITY_HIGH);
 
   comp->priv->seqnum_to_restart_task = 0;
-  comp->priv->waiting_for_buffer = FALSE;
+  comp->priv->waiting_serialized_query_or_buffer = FALSE;
 
   comp->priv->updating_reason = COMP_UPDATE_STACK_NONE;
   GST_OBJECT_LOCK (comp);
@@ -2257,8 +2280,8 @@ _is_ready_to_restart_task (NleComposition * comp, GstEvent * event)
   if (comp->priv->seqnum_to_restart_task == seqnum) {
     gchar *name = g_strdup_printf ("%s-new-stack__%" GST_TIME_FORMAT "--%"
         GST_TIME_FORMAT "", GST_OBJECT_NAME (comp),
-        GST_TIME_ARGS (comp->priv->segment_start),
-        GST_TIME_ARGS (comp->priv->segment_stop));
+        GST_TIME_ARGS (comp->priv->current_stack_start),
+        GST_TIME_ARGS (comp->priv->current_stack_stop));
 
     GST_INFO_OBJECT (comp, "Got %s with proper seqnum"
         " done with stack reconfiguration %" GST_PTR_FORMAT,
@@ -2273,7 +2296,7 @@ _is_ready_to_restart_task (NleComposition * comp, GstEvent * event)
       return TRUE;
     }
 
-    priv->waiting_for_buffer = TRUE;
+    priv->waiting_serialized_query_or_buffer = TRUE;
     return FALSE;
 
   } else if (comp->priv->seqnum_to_restart_task) {
@@ -2314,9 +2337,23 @@ _commit_func (NleComposition * comp, UpdateCompositionData * ucompo)
     g_signal_emit (comp, _signals[COMMITED_SIGNAL], 0, TRUE);
 
   } else {
-    /* And update the pipeline at current position if needed */
+    gboolean reverse;
 
+    /* And update the pipeline at current position if needed */
     update_start_stop_duration (comp);
+
+    reverse = (priv->segment->rate < 0.0);
+    if (!reverse) {
+      GST_DEBUG_OBJECT (comp,
+          "Setting segment->start to curpos:%" GST_TIME_FORMAT,
+          GST_TIME_ARGS (curpos));
+      priv->segment->start = curpos;
+    } else {
+      GST_DEBUG_OBJECT (comp,
+          "Setting segment->stop to curpos:%" GST_TIME_FORMAT,
+          GST_TIME_ARGS (curpos));
+      priv->segment->stop = curpos;
+    }
     update_pipeline (comp, curpos, ucompo->seqnum, COMP_UPDATE_STACK_ON_COMMIT);
 
     if (!priv->current) {
@@ -2338,18 +2375,18 @@ _update_pipeline_func (NleComposition * comp, UpdateCompositionData * ucompo)
 
   _post_start_composition_update (comp, ucompo->seqnum, ucompo->reason);
 
-  /* Set up a non-initial seek on segment_stop */
+  /* Set up a non-initial seek on current_stack_stop */
   reverse = (priv->segment->rate < 0.0);
   if (!reverse) {
     GST_DEBUG_OBJECT (comp,
-        "Setting segment->start to segment_stop:%" GST_TIME_FORMAT,
-        GST_TIME_ARGS (priv->segment_stop));
-    priv->segment->start = priv->segment_stop;
+        "Setting segment->start to current_stack_stop:%" GST_TIME_FORMAT,
+        GST_TIME_ARGS (priv->current_stack_stop));
+    priv->segment->start = priv->current_stack_stop;
   } else {
     GST_DEBUG_OBJECT (comp,
-        "Setting segment->stop to segment_start:%" GST_TIME_FORMAT,
-        GST_TIME_ARGS (priv->segment_start));
-    priv->segment->stop = priv->segment_start;
+        "Setting segment->stop to current_stack_start:%" GST_TIME_FORMAT,
+        GST_TIME_ARGS (priv->current_stack_start));
+    priv->segment->stop = priv->current_stack_start;
   }
 
   seek_handling (comp, ucompo->seqnum, COMP_UPDATE_STACK_ON_EOS);
@@ -2715,7 +2752,7 @@ _deactivate_stack (NleComposition * comp, gboolean flush_downstream)
 {
   GstPad *ptarget;
 
-  GST_INFO_OBJECT (comp, "Deactivating current stack (flushing downstream: %d",
+  GST_INFO_OBJECT (comp, "Deactivating current stack (flushing downstream: %d)",
       flush_downstream);
   _set_current_bin_to_ready (comp, flush_downstream);
 
@@ -2818,8 +2855,8 @@ _activate_new_stack (NleComposition * comp)
   if (!priv->current) {
     if ((!priv->objects_start)) {
       nle_composition_reset_target_pad (comp);
-      priv->segment_start = 0;
-      priv->segment_stop = GST_CLOCK_TIME_NONE;
+      priv->current_stack_start = 0;
+      priv->current_stack_stop = GST_CLOCK_TIME_NONE;
     }
 
     GST_DEBUG_OBJECT (comp, "Nothing else in the composition"
@@ -2859,9 +2896,9 @@ _set_real_eos_seqnum_from_seek (NleComposition * comp, GstEvent * event)
   gboolean reverse = (priv->segment->rate < 0);
   gint stack_seqnum = gst_event_get_seqnum (event);
 
-  if (reverse && GST_CLOCK_TIME_IS_VALID (priv->segment_start))
+  if (reverse && GST_CLOCK_TIME_IS_VALID (priv->current_stack_start))
     should_check_objects = TRUE;
-  else if (!reverse && GST_CLOCK_TIME_IS_VALID (priv->segment_stop))
+  else if (!reverse && GST_CLOCK_TIME_IS_VALID (priv->current_stack_stop))
     should_check_objects = TRUE;
 
   if (should_check_objects) {
@@ -2871,8 +2908,8 @@ _set_real_eos_seqnum_from_seek (NleComposition * comp, GstEvent * event)
       if (!NLE_IS_SOURCE (object))
         continue;
 
-      if ((!reverse && priv->segment_stop < object->stop) ||
-          (reverse && priv->segment_start > object->start)) {
+      if ((!reverse && priv->current_stack_stop < object->stop) ||
+          (reverse && priv->current_stack_start > object->start)) {
         priv->next_eos_seqnum = stack_seqnum;
         g_atomic_int_set (&priv->real_eos_seqnum, 0);
         return FALSE;
@@ -2947,14 +2984,14 @@ update_pipeline (NleComposition * comp, GstClockTime currenttime, gint32 seqnum,
   stack = get_clean_toplevel_stack (comp, &currenttime, &new_start, &new_stop);
   samestack = are_same_stacks (priv->current, stack);
 
-  /* set new segment_start/stop (the current zone over which the new stack
+  /* set new current_stack_start/stop (the current zone over which the new stack
    * is valid) */
   if (priv->segment->rate >= 0.0) {
-    priv->segment_start = currenttime;
-    priv->segment_stop = new_stop;
+    priv->current_stack_start = currenttime;
+    priv->current_stack_stop = new_stop;
   } else {
-    priv->segment_start = new_start;
-    priv->segment_stop = currenttime;
+    priv->current_stack_start = new_start;
+    priv->current_stack_stop = currenttime;
   }
 
 # if 0
@@ -2965,11 +3002,11 @@ update_pipeline (NleComposition * comp, GstClockTime currenttime, gint32 seqnum,
   gboolean startchanged, stopchanged;
 
   if (priv->segment->rate >= 0.0) {
-    startchanged = priv->segment_start != currenttime;
-    stopchanged = priv->segment_stop != new_stop;
+    startchanged = priv->current_stack_start != currenttime;
+    stopchanged = priv->current_stack_stop != new_stop;
   } else {
-    startchanged = priv->segment_start != new_start;
-    stopchanged = priv->segment_stop != currenttime;
+    startchanged = priv->current_stack_start != new_start;
+    stopchanged = priv->current_stack_stop != currenttime;
   }
 
   if (samestack) {
@@ -2995,8 +3032,8 @@ update_pipeline (NleComposition * comp, GstClockTime currenttime, gint32 seqnum,
 
   /* Unlock all elements in new stack */
   GST_INFO_OBJECT (comp, "Setting current stack [%" GST_TIME_FORMAT " - %"
-      GST_TIME_FORMAT "]", GST_TIME_ARGS (priv->segment_start),
-      GST_TIME_ARGS (priv->segment_stop));
+      GST_TIME_FORMAT "]", GST_TIME_ARGS (priv->current_stack_start),
+      GST_TIME_ARGS (priv->current_stack_stop));
   priv->current = stack;
 
   if (priv->current) {
